@@ -1,21 +1,15 @@
 """Package providing functionality for reading .ACQ format files."""
+
+import contextlib
+
+__all__ = ["decode_file", "encode"]
 from pkg_resources import DistributionNotFound, get_distribution
 
-from . import codec, writers
-from .read_acq import (
-    Ancillary,
-    convert_file,
-    convert_h5,
-    decode_file,
-    decode_files,
-    encode,
-)
+from .read_acq import decode_file, encode
 
-try:
+with contextlib.suppress(DistributionNotFound):
     __version__ = get_distribution(__name__).version
-except DistributionNotFound:
-    # package is not installed
-    pass
 
 del get_distribution
 del DistributionNotFound
+del contextlib
